/*
 DATA ANALYSIS FILES FOR "CIVIL WAR, REINTEGRATION, AND GENDER IN NORTHERN UGANDA" 
 BY ANNAN, BLATTMAN, MAZURANA, AND CARLSON (2011)
 JUNE 2013
 STATA 12 CODE
 
NOTES:
	Full replication materials for the entire Survey of War Affected Youth (SWAY) 
	and all associated papers, including a data manual and full original surveys, 
	are available at http://chrisblattman.com

INSTRUCTIONS FOR THIS DO FILE
	1. Copy the full replication folder to your computer 
	2. Update the link below to point to the replication folder on your computer.
	3. All results will be saved in your replication folder under Data/Output/Civil War.
 
TABLE OF CONTENTS:
	1. Data preparation
	2. Analysis
		a. Table 1: Determinants of Abduction (By Gender)
		b. Table 2: Average Impacts of Abduction (By Gender)
		c. Table 3: Reintegration Outcomes and War Experiences
		d. Table 4: Average Impacts of Years Since Return (By Gender)
		e. Table 5: Return Outcomes (For Youth Abducted More Than 2 Weeks)
		f. Table 6: Reinsertion Outcomes and War Experiences
		g. Figure 1: Schooling by Age
	3. Figures and analysis reported in paper but not included in tables
		a. Table A: Summary statistics on abduction violence (All Respondents)
		b. Table B: Summary statistics on abduction experiences (Abductees Only)
		c. Table C: Summary statistics on outcomes (All respondents)
	4. Other statistics quoted in the Paper but not in Tables
*/


// Set up data set
   clear
   set mem 40m
   set matsize 400
   set more off
   cap log close
   ssc install margeff, replace
   
cd "YOUR DIRECTORY\SWAY.Replication.June2013"

* 1) DATA PREPARATION

use "Data/SWAY_I&II_June2013.dta", clear

//* Globals *//

	* Note: the A in A14-A29 stands for age, so A14 means age 14
	* Note: the C in C_ach-C_paj stands for Camp, so C_ach is the name of a camp
	global AC "A14-A29 C_ach-C_paj" 
	
	* Note: the G in G1_18-G1_22 is referring to the interaction between age and camp
	global ACG "A14-A29 C_ach-C_paj G1_18-G1_22 G2_14 G2_22 G3_14-G3_18 G4_14-G4_22 G5_14-G5_22 G6_14-G6_22 G7_14-G7_22 G8_14-G8_22" 
	
	* Note: Phase 1 refers to data collection on males, and Phase 2 refers to data collection on females
	global AC2 "age age_2 age_3 phase2_age phase2_age2 phase2_age3 CC*"
	
	* Note: AA* is the interaction between age and phase, and CC* is the interaction between camp and phase
	global AC3 "AA* CC*" 
	
	global ctrls "fthr_ed0 fthr_ed4 fthr_ed7 mthr_ed0 mthr_ed4 mthr_ed7 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_size96_2 hh_size96_3 hh_size96_4 hh_land hh_land_2 hh_land_3 hh_land_4 hh_cattle hh_cattle_2 hh_cattle_3 hh_cattle_4 hh_stock hh_stock_2 hh_stock_3 hh_stock_4 hh_plow"
	global ctrl "fthr_ed mthr_ed no_fthr96 no_mthr96 hh_size96 wealth96 hh_fthr_frm"

	* Cleaning
	foreach v of varlist abd_no_mthr abd_no_fthr abd_sing_par abd_orph {
	 replace `v' = 0 if abd==1 & found==1 & `v'==.
	 }
	
	replace children=0 if children==1 & found==1
	replace absentee=0 if absentee==.
	replace died=0 if died==.
	
	la var abd_lgth "Years abducted"
	
	
//* New variables *//
	gen iron_fist=cond(abd_yr>=2002 & abd==1,1,0)
	la var iron_fist "Abducted on or after 2002 (Operation Iron Fist)"
	
	egen wealth96 = std(hh_wealth96)
	la var wealth96 "Index of wealth (Standard normal)"
	
	gen abd_phase2=abd*phase2
	gen abd_phase1=abd*(1-phase2)
	
	foreach var of varlist age hh_size96 hh_land hh_cattle hh_stock {
	  gen `var'_2=`var'^2
	  gen `var'_3=`var'^3
	  gen `var'_4=`var'^4
	  }
	
	gen phase2_age = age*phase2
	gen phase2_age2 = age_2*phase2
	gen phase2_age3 = age_3*phase2
	
	replace back=.25 if back<.25 & back!=.
	gen back_phase2=back*phase2
	
	replace fam_prob_now=0 if phase2==0 & fam_prob_ever==0
	replace fam_prob_now=. if twoweek==0
	replace comm_prob_now=0 if phase2==0 & fam_prob_ever==0
	replace comm_prob_now=. if twoweek==0
	
	replace bush_mom=0 if bush_mom==.
	replace lead=0 if lead==.

	* Distress percentiles
	sum distress, detail
	gen distress75=0
	replace distress75=1 if distress>5.7
	replace distress75=. if distress==.
	svy: tab distress75
	
	gen phase1=0
	replace phase1=1 if phase2==0 & phase2!=.
	
	replace fighter=0 if abd==1 & twoweek==0
	replace loyal=0 if abd==1 & twoweek==0

//* Assume 0 for certain roles if abd <2 weeks *//
	foreach y in magic command reward depend gun gun_keep fighter stay safer loyal loyal_often lead orders {
	  replace `y'=0 if `y'==.
	  }
	replace gun=. if phase2==1
	replace gun_keep=. if phase2==1
	replace gun_mo=. if phase2==1
	replace fighter=. if phase2==0
	replace magic=. if phase2==1
	replace command=. if phase2==1
	replace depend=. if phase2==1
	
	replace comm_prob_now=0 if comm_prob_ever!=. & comm_prob_now==.
	replace fam_prob_now=0 if fam_prob_ever!=. & fam_prob_now==.
	
//*Label Variables*//
	la var phase1 "Phase I indicator"
	la var age_2 "Respondent age squared"
	la var age_3 "Respondent age cubed"
	la var age_4 "Respondent age to the fourth power"
	la var phase2_age "Phase II Respondent age"
	la var phase2_age2 "Phase II Respondent age squared"
	la var phase2_age3 "Phase II Respondent age cubed"
	la var abd_phase2 "Phase II Ever abducted"
	la var abd_phase1 "Phase I Ever abducted"
	la var back_phase2 "Phase II Years since returning from bush"
	la var distress75 "In the top 25% on the index of emotional distress"
	la var blame_not_strong "Equals 1 if thinks bad things happened to them because they were not strong enough to stop them from happening"
	la var blame_parents "Equals 1 if thinks parents are to blame for what happened to them"
	la var blame_self "Equals 1 if thinks they are to blame for what happened to them"
	la var blame_haunted "Equals 1 if they feel haunted by spirits"
	la var blame_causetrouble_fam "Equals 1 if they feel they have caused trouble to their family"
	la var blame_guilt "Equals 1 if they feel guilt about things that have happened to them"
	la var blame_causetrouble_comm "Equals 1 if they feel they have caused trouble for community"
	la var blame_badperson "Equals 1 if neighbors see them as bad person because of anything they did"
	la var blame_lra "Equals 1 if they think Kony and LRA leaders are to blame for what happened to them"
	la var blame_god "Equals 1 if they believe bad things happened to them because it was God's plan"
	la var blame_cursed "Equals 1 if they believe bad things happened to them because they were cursed"
	la var neighbor_trouble "Equals 1 if had trouble getting along with neighbors since the beginning of the year"
	la var important_comm "Equals 1 if they feel like an important part of their community"
	la var ethnic_attitude_med "Equals 1 if considers people from other northern ethnic groups to be somewhat like brothers and sisters"
	la var ethnic_attitude_hi "Equals 1 if considers people from other northern ethnic group to be very much like brothers and sisters"
	la var autoc_good "Equals 1 if thinks having an autocratic government is good"
	la var army_good "Equals 1 if thinks rule by the army is good"
	la var multiparty_bad "Equals 1 if thinks having many political parties compete democratically is bad"
	la var singleparty_good "Equals 1 if thinks rule by a single party is good"
	la var antidemocratic "Equals 1 if has anti-democratic beliefs about forms of government"
	la var hh_size96_2 "Household size in 1996 squared"
	la var hh_size96_3 "Household size in 1996 cubed"
	la var hh_size96_4 "Household size in 1996 to the fouth power"
	la var hh_cattle_2 "Household cattle squared"
	la var hh_cattle_3 "Household cattle cubed"
	la var hh_cattle_4 "Household cattle to the fourth power"
	la var hh_land_2 "Household land squared"
	la var hh_land_3 "Household land cubed"
	la var hh_land_4 "Household land to the fourth power"
	la var hh_stock_2 "Household livestock squared"
	la var hh_stock_3 "Household livestock cubed"
	la var hh_stock_4 "Household livestock to the fourth power"


//*Re-order variables in dataset*// 
	#delimit ;
	order
	
	IDENTIFYING_VARIABLES
	id
	phase1
	phase2
	age
	age_2
	age_3
	age_4
	phase2_age
	phase2_age2
	phase2_age3
	sample
	found
	absentee
	died
	no_return
	nosurvive
	lt_abd
	district
	camp
	
	EMPLOYMENT_VARIABLES
	emp_mo
	emp_d_mo
	wage_mo
	prof
	aindex
	wealth96
	
	EDUCATION_VARIABLES
	educ
	illiterate
	literate
	inschool
	ngo_paid
	secskool
	university
	voc
	educ0
	adult_ed
	
	HEALTH_VARIABLES
	injury
	lra_inj
	hiv_aware
	fight
	
	ABDUCTION_VARIABLES
	abd
	abd_phase2
	abd_phase1
	iron_fist
	abd_age
	abd_yr
	yr_abd
	abd_l
	longest_abd
	abd_lgth
	abd_per
	yr_ret
	age_back
	back
	back_phase2
	twoweek
	abd_no_mthr
	abd_no_fthr
	abd_sing_par
	abd_orph
	educ_abd
	inschool_abd
	emp_abd
	occ_abd
	
	WAR_EXPERIENCES_VARIABLES
	force_wife
	force_wife_months
	fighter
	bush_mom
	kill
	kill_sol
	tied
	carry
	abusedead
	harm_fam
	viol_received
	viol_witnessed
	viol_experienced
	viol_loss
	viol_personal
	viol_perp
	viol_sex
	viol_total
	gun
	gun_keep
	gun_mo
	depend
	command
	rewarded
	loyal
	loyal_often
	leader
	lead
	orders
	magic
	stay
	safer
	threats
	threats_only
	indoctrinate
	ceremony
	harm_civ
	beaten
	attacked
	army
	
	RETURN_EXPERIENCES_VARIABLES
	rescued
	released
	released_1w
	released_2w
	escaped
	reception
	services
	updf
	amnesty
	ret_skool
	ret_home
	ret_par_hw
	ret_pr_gr_hw
	ret_pr_gr_hw_sib
	distress
	distress75
	prosocial
	hostility
	hostile
	quarrelsome
	threaten
	elders_disobey
	support
	allegiance_total
	allegiance_modhi
	blame_not_strong
	blame_parents
	blame_self
	blame_haunted
	blame_causetrouble_fam
	blame_guilt
	blame_causetrouble_comm
	blame_badperson
	blame_lra
	blame_god
	blame_cursed
	
	FAMILY_COMMUNITY_VARIABLES
	comm_understand
	comm_important
	comm_quar
	comm_sisters
	comm_connect
	comm_prob_ever
	comm_prob_now
	comm_prob_better
	fam_prob_ever
	fam_prob_now
	fam_prob_better
	fam_caring
	fam_comfort
	fam_connect
	fam_problems
	fam_quarrel
	neighbor_trouble
	important_comm
	
	SOC_POL_PARTICIPATION_VARIABLES
	groups
	group
	g_peace
	g_drama
	g_farm
	g_water
	g_skool
	g_sport
	g_church
	g_oth
	comm_mobil
	volunteer
	vote05
	pol_job
	ethnic_attitude_med
	ethnic_attitude_hi
	autoc_good
	army_good
	multiparty_bad
	singleparty_good
	antidemocratic
	
	HH_BACKGROUND_VARIABLES
	married
	children
	fthr_ed
	fthr_ed0
	fthr_ed4
	fthr_ed7
	fthr_edhi
	mthr_ed
	mthr_ed0
	mthr_ed4
	mthr_ed7
	mthr_edhi
	no_fthr96
	no_mthr96
	orphan96
	catholic
	church
	hh_size96
	hh_size96_2
	hh_size96_3
	hh_size96_4
	hh_wealth96
	hh_fthr_frm
	hh_plow
	hh_cattle_any
	hh_cattle
	hh_cattle_2
	hh_cattle_3
	hh_cattle_4
	hh_land_any
	hh_land
	hh_land_2
	hh_land_3
	hh_land_4
	hh_stock_any
	hh_stock
	hh_stock_2
	hh_stock_3
	hh_stock_4
	radio
	
	
	WEIGHTS
	i_weight
	f_weight
	f_weight_abs
	w_samp
	w_abs
	w_sel
	w_sel_abs
	stratum
	
	LOCATION_AGE_ABDYR_INDICATORS
	A14
	A15
	A16
	A17
	A18
	A19
	A20
	A21
	A22
	A23
	A24
	A25
	A26
	A27
	A28
	A29
	A30
	A31
	A32
	A33
	A34
	A35
	C_ach
	C_akw
	C_ata
	C_kma
	C_oro
	C_pad
	C_paj
	C_pal
	CC0_ach
	CC0_akw
	CC0_ata
	CC0_kma
	CC0_oro
	CC0_pad
	CC0_paj
	CC0_pal
	CC1_ach
	CC1_akw
	CC1_ata
	CC1_kma
	CC1_oro
	CC1_pad
	CC1_paj
	CC1_pal
	Y1994
	Y1995
	Y1996
	Y1997
	Y1998
	Y1999
	Y2000
	Y2001
	Y2002
	Y2003
	Y2004
	abd_l_1d
	abd_l_2to6d
	abd_l_1to2w
	abd_l_2to4w
	abd_l_1_2
	abd_l_2_4
	abd_l_4_7
	abd_l_7_11
	abd_l_12_16
	abd_l_16_25
	abd_l_25_50
	abd_l_50up
	G1_14_17
	G1_18_21
	G1_22_25
	G1_26_30
	G2_14_17
	G2_18_21
	G2_22_25
	G2_26_30
	G3_14_17
	G3_18_21
	G3_22_25
	G3_26_30
	G4_14_17
	G4_18_21
	G4_22_25
	G4_26_30
	G5_14_17
	G5_18_21
	G5_22_25
	G5_26_30
	G6_14_17
	G6_18_21
	G6_22_25
	G6_26_30
	G7_14_17
	G7_18_21
	G7_22_25
	G7_26_30
	G8_14_17
	G8_18_21
	G8_22_25
	G8_26_30
	G1_31_plus
	G2_31_plus
	G3_31_plus
	G4_31_plus
	G5_31_plus
	G6_31_plus
	G7_31_plus
	G8_31_plus
	nosurvivetab
	AA0_14
	AA0_15
	AA0_16
	AA0_17
	AA0_18
	AA0_19
	AA0_20
	AA0_21
	AA0_22
	AA0_23
	AA0_24
	AA0_25
	AA0_26
	AA0_27
	AA0_28
	AA0_29
	AA0_30
	AA1_14
	AA1_15
	AA1_16
	AA1_17
	AA1_18
	AA1_19
	AA1_20
	AA1_21
	AA1_22
	AA1_23
	AA1_24
	AA1_25
	AA1_26
	AA1_27
	AA1_28
	AA1_29
	AA1_30
	AA1_31
	AA1_32
	AA1_33
	AA1_34
	AA1_35;
	
	#delimit cr
	
	svyset, clear
	save "Data/tempdata/temp_all", replace


//* Drop all females ages 31-35*//
	svyset, clear
	drop if phase2==1 & age>30
	keep if found==1
	save "Data/tempdata/temp_under30.dta", replace
	
	
//* Database of abductions (each individual has separate line for each abduction) *// 
	use "Data/SWAY_I&II_ABD_June2013.dta", clear
	svyset [pw=i_weight], strata(stratum) psu(id)
	
	gen iron_fist=cond(abd_yr>=2002 & abd==1,1,0)
	la var iron_fist "Abducted on or after 2002 (Operation Iron Fist)"
	
	egen wealth96 = std(hh_wealth96)
	la var wealth96 "Index of wealth (Standard normal)"
	
	foreach var of varlist age hh_size96 hh_land hh_cattle hh_stock {
	  gen `var'_2=`var'^2
	  gen `var'_3=`var'^3
	  gen `var'_4=`var'^4
	  }
	
	foreach v of varlist age abd_age mthr_ed fthr_ed no_fthr96 no_mthr96 wealth96 iron_fist abd_yr {
	 gen phase2_`v' = `v'*phase2
	 gen phase1_`v' = `v'*(1-phase2)
	 la var phase2_`v' "Phase 2 dummy X `v'"
	 la var phase1_`v' "Phase 1 dummy X `v'"
	 }
	
	gen escape_other= cond(escaped==1 & esc_bat==0,1,0)
	la var escape_other "Escaped outside of battle"
	replace esc_bat=0 if escape_other==0 & esc_bat==.
	replace escaped=0 if escape_other==0 & escaped==.
	
	foreach var of varlist escaped rescued released_2w {
	replace `var'=0 if `var'==.
	}
	
//*Label Variables*//
	la var abdn "Number of times they have been with the LRA, even for only a few hours"
	la var rescued "Equals 1 if rescued from abduction by LRA"
	la var escaped "Equals 1 if escaped from abduction by LRA"
	la var esc_knew "Equals 1 if knew very well where they were when they escaped from the LRA"
	la var esc_knew2 "Equals 1 if knew very well or roughly where they were when they escaped from the LRA"
	la var esc_battle "Equals 1 if escaped from the LRA during a battle or ambush"
	la var esc_ranaway "Equals 1 if escaped from the LRA by running away"
	la var f_weight "Rounded i_weight (for use as fweights)
	la var f_weight_abs "Rounded w_abs (for use as fweights) 
	la var Y1989 "Abduction year indicator: 1989"
	la var Y1990 "Abduction year indicator: 1990"
	la var Y1991 "Abduction year indicator: 1991"
	la var Y1992 "Abduction year indicator: 1992"
	la var Y1993 "Abduction year indicator: 1993"
	la var Y1994 "Abduction year indicator: 1994"
	la var Y1995 "Abduction year indicator: 1995"
	la var Y1996 "Abduction year indicator: 1996"
	la var Y1997 "Abduction year indicator: 1997"
	la var Y1998 "Abduction year indicator: 1998"
	la var Y1999 "Abduction year indicator: 1999"
	la var Y2000 "Abduction year indicator: 2000"
	la var Y2001 "Abduction year indicator: 2001"
	la var Y2002 "Abduction year indicator: 2002"
	la var Y2003 "Abduction year indicator: 2003"
	la var Y2004 "Abduction year indicator: 2004"
	la var Y2005 "Abduction year indicator: 2005"
	la var CC0_ach "Phase 1 Acholibur Dummy"
	la var CC0_akw "Phase 1 Akwang Dummy"
	la var CC0_ata "Phase 1 Atanga Dummy"
	la var CC0_kma "Phase 1 K. Matidi Dummy"
	la var CC0_oro "Phase 1 Orom Dummy"
	la var CC0_pad "Phase 1 Pader Dummy"
	la var CC0_paj "Phase 1 Pajule Dummy"
	la var CC0_pal "Phase 1 Palabek Dummy"
	la var CC1_ach "Phase 2 Acholibur Dummy" 
	la var CC1_akw "Phase 2 Akwang Dummy"
	la var CC1_ata "Phase 2 Atanga Dummy"
	la var CC1_kma "Phase 2 K. Matidi Dummy"
	la var CC1_oro "Phase 2 Orom Dummy"
	la var CC1_pad "Phase 2 Pader Dummy"
	la var CC1_paj "Phase 2 Pajule Dummy"
	la var CC1_pal "Phase 2 Palabek Dummy"
	la var abd_l_1d "Total abduction: <1 day"
	la var abd_l_2to6d "Total abduction: 2-6 days"
	la var abd_l_1w "Total abduction: 1 week"
	la var abd_l_1to4w "Total abduction: 1-4 weeks"
	la var abd_l_1_2 "Total abduction: 1-2 months"
	la var abd_l_2_4 "Total abduction: 2-4 months"
	la var abd_l_4_7 "Total abduction: 4-7 months"
	la var abd_l_7_11 "Total abduction: 7-11 months"
	la var abd_l_12_16 "Total abduction: 12-16 months"
	la var abd_l_16_25 "Total abduction: 16-25 months"
	la var abd_l_25_50 "Total abduction: 25-50 months"
	la var abd_l_50up "Total abduction: >50 months"
	la var labd_lgth "Natural logarithm of abduction length"
	la var abd_age2 "Abduction age squared"
	la var age_2 "Respondent age squared"
	la var age_3 "Respondent age cubed"
	la var age_4 "Respondent age to the fourth power"
	la var hh_size96_2 "Household size in 1996 squared"
	la var hh_size96_3 "Household size in 1996 cubed"
	la var hh_size96_4 "Household size in 1996 to the fouth power"
	la var hh_land_2 "Household land squared"
	la var hh_land_3 "Household land cubed"
	la var hh_land_4 "Household land to the fourth power"
	la var hh_cattle_2 "Household cattle squared"
	la var hh_cattle_3 "Household cattle cubed"
	la var hh_cattle_4 "Household cattle to the fourth power"
	la var hh_stock_2 "Household livestock squared"
	la var hh_stock_3 "Household livestock cubed"
	la var hh_stock_4 "Household livestock to the fourth power"

//*Generate dividers to organize dataset*//
	gen IDENTIFYING_VARIABLES=.
	la var IDENTIFYING_VARIABLES "========================================"
	gen ABDUCTION_VARIABLES=.
	la var ABDUCTION_VARIABLES "========================================"
	gen WAR_EXPERIENCES_VARIABLES=.
	la var WAR_EXPERIENCES_VARIABLES "========================================"
	gen RETURN_EXPERIENCES_VARIABLES=.
	la var RETURN_EXPERIENCES_VARIABLES "========================================"
	gen HH_BACKGROUND_VARIABLES=.
	la var HH_BACKGROUND_VARIABLES "========================================"
	gen WEIGHTS=.
	la var WEIGHTS "========================================"
	gen LOCATION_AGE_ABDYR_INDICATORS=.
	la var LOCATION_AGE_ABDYR_INDICATORS"========================================"
	
//*Re-order variables in the dataset*//
	#delimit ;
	order
	
	IDENTIFYING_VARIABLES
	id
	camp
	no_return
	sample
	absentee
	found
	died
	age
	age_2
	age_3
	age_4
	phase2_age
	phase1_age
	phase2
	
	ABDUCTION_VARIABLES
	abd
	abdn
	abd_lgth
	labd_lgth
	abdage
	abd_age
	abd_age2
	age_back
	twoweek
	pscore_abd
	yr_abd
	abd_yr
	phase2_abd_yr
	phase1_abd_yr
	abd_before
	phase2_abd_age
	phase1_abd_age
	iron_fist
	phase2_iron_fist
	phase1_iron_fist
	educ_abd
	inschool_abd
	emp_abd
	abd_per
	
	WAR_EXPERIENCES_VARIABLES
	force_wife
	bush_mom
	lead
	
	RETURN_EXPERIENCES_VARIABLES
	released
	released_1w
	released_2w
	rescued
	escaped
	escape_other
	esc_knew
	esc_knew2
	esc_battle
	esc_ranaway
	
	HH_BACKGROUND_VARIABLES
	no_fthr96
	phase2_no_fthr96
	phase1_no_fthr96
	no_mthr96
	phase2_no_mthr96
	phase1_no_mthr96
	orphan96
	fthr_ed
	phase2_fthr_ed
	phase1_fthr_ed
	mthr_ed
	phase2_mthr_ed
	phase1_mthr_ed
	fthr_ed0
	fthr_ed4
	fthr_ed7
	fthr_edhi
	mthr_ed0
	mthr_ed4
	mthr_ed7
	mthr_edhi
	catholic
	hh_size96
	hh_size96_2
	hh_size96_3
	hh_size96_4
	hh_wealth96
	wealth96
	phase2_wealth96
	phase1_wealth96
	hh_fthr_frm
	hh_land_any
	hh_land
	hh_land_2
	hh_land_3
	hh_land_4
	hh_land_miss
	hh_cattle_any
	hh_cattle
	hh_cattle_2
	hh_cattle_3
	hh_cattle_4
	hh_cattle_miss
	hh_stock_any
	hh_stock
	hh_stock_2
	hh_stock_3
	hh_stock_4
	hh_stock_miss
	hh_plow
	
	WEIGHTS
	w_samp
	w_abs
	w_sel
	i_weight
	stratum
	f_weight
	f_weight_abs
	
	LOCATION_AGE_ABDYR_INDICATORS
	A14
	A15
	A16
	A17
	A18
	A19
	A20
	A21
	A22
	A23
	A24
	A25
	A26
	A27
	A28
	A29
	A30
	A31
	A32
	A33
	A34
	A35
	C_ach
	C_akw
	C_ata
	C_kma
	C_oro
	C_pad
	C_paj
	C_pal
	CC0_ach
	CC0_akw
	CC0_ata
	CC0_kma
	CC0_oro
	CC0_pad
	CC0_paj
	CC0_pal
	CC1_ach
	CC1_akw
	CC1_ata
	CC1_kma
	CC1_oro
	CC1_pad
	CC1_paj
	CC1_pal
	Y1989
	Y1990
	Y1991
	Y1992
	Y1993
	Y1994
	Y1995
	Y1996
	Y1997
	Y1998
	Y1999
	Y2000
	Y2001
	Y2002
	Y2003
	Y2004
	Y2005
	abd_l_1d
	abd_l_2to6d
	abd_l_1w
	abd_l_1to4w
	abd_l_1_2
	abd_l_2_4
	abd_l_4_7
	abd_l_7_11
	abd_l_12_16
	abd_l_16_25
	abd_l_25_50
	abd_l_50up
	G1_14_17
	G1_18_21
	G1_22_25
	G1_26_30
	G1_31_plus
	G2_14_17
	G2_18_21
	G2_22_25
	G2_26_30
	G2_31_plus
	G3_14_17
	G3_18_21
	G3_22_25
	G3_26_30
	G3_31_plus
	G4_14_17
	G4_18_21
	G4_22_25
	G4_26_30
	G4_31_plus
	G5_14_17
	G5_18_21
	G5_22_25
	G5_26_30
	G5_31_plus
	G6_14_17
	G6_18_21
	G6_22_25
	G6_26_30
	G6_31_plus
	G7_14_17
	G7_18_21
	G7_22_25
	G7_26_30
	G7_31_plus
	G8_14_17
	G8_18_21
	G8_22_25
	G8_26_30
	G8_31_plus
	AA0_14
	AA0_15
	AA0_16
	AA0_17
	AA0_18
	AA0_19
	AA0_20
	AA0_21
	AA0_22
	AA0_23
	AA0_24
	AA0_25
	AA0_26
	AA0_27
	AA0_28
	AA0_29
	AA0_30
	AA1_14
	AA1_15
	AA1_16
	AA1_17
	AA1_18
	AA1_19
	AA1_20
	AA1_21
	AA1_22
	AA1_23
	AA1_24
	AA1_25
	AA1_26
	AA1_27
	AA1_28
	AA1_29
	AA1_30
	AA1_31
	AA1_32
	AA1_33
	AA1_34
	AA1_35;
	
	#delimit cr
	keep if abd==1 & found==1
	
	svyset, clear
	save "Data/tempdata/temp_ABD_all", replace
	


* 2) ANALYSIS

//* Table 1: Determinants of Abduction (By Gender) *//
	
	use "Data/tempdata/temp_ABD_all", clear
	svyset [pw=i_weight], strata(stratum) psu(id)
	
	qui svy: reg age abd C_ach-C_paj hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se) replace
	foreach n of numlist 0 1 {
	
	use "Data/tempdata/temp_all.dta", clear
	svyset camp [pweight=i_weight], strata(stratum)
	
	qui svy, sub(if phase2==`n'): reg age abd C_ach-C_paj hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	qui svy, sub(if phase2==`n'): reg hh_fthr_frm abd $ACG hh_size96 hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	qui svy, sub(if phase2==`n'): reg hh_size96 abd $ACG hh_fthr_frm hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	qui svy, sub(if phase2==`n'): reg wealth96 abd $ACG hh_fthr_frm hh_size96
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	
	 use "Data/tempdata/temp_under30.dta", replace
	 svyset [pweight=w_abs], strata(stratum) psu(camp)
	
	qui svy, sub(if phase2==`n'): reg fthr_ed abd $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	qui svy, sub(if phase2==`n'): reg mthr_ed abd $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	qui svy, sub(if phase2==`n'): reg no_fthr96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_mthr96 hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	qui svy, sub(if phase2==`n'): reg no_mthr96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow
		outreg2 abd using "Data/Output/Civil War/table1.xls", br bdec(2) sdec(3) label nocons aster(se)
	}


//* Table 2: Average Impacts of Abduction (By Gender) *//

	use "Data/tempdata/temp_under30.dta", clear
	
	//*Summary Statistics for columns 1 4 in Table 2*//
	
		cap matrix drop E
	
		global sumstatsT3 "educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted fight hostile neighbor_trouble antidemocratic"
	
		*Phase 2
		foreach x in $sumstatsT3 {
		sum `x' [iw=w_abs] if abd==0 & phase2==1 
			sca c_mu2 = r(mean)
			sca c_sd2 = r(sd)
			sca obs2 = r(N)
		
		*Phase 1
		sum `x'  [iw=w_abs] if abd==0 & phase2==0
			sca c_mu1 = r(mean)
			sca c_sd1 = r(sd)
			sca obs1 = r(N)
		
			matrix E = nullmat(E)\(c_mu2, c_sd2, obs2, c_mu1, c_sd1, obs1)
		}
	
		local cnames `" "Mean (Females)" "Std. Dev. (Females)" "Obs. (Females)" "Mean (Males)" "Std. Dev. (Males)" "Obs. (Males)" "'
		local rname	
			
		foreach x in $sumstatsT3 {
			local lbl  `x'
			local rname `" `rname' `lbl' "'
		}	
		
		xml_tab E, save("Data/Output/Civil War/table3-sumstats.xls") replace noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 11) format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))

	//*Columns 2, 5, 7, and 8 in Table 2*//
		svyset [pweight=w_sel_abs], strata(stratum) psu(camp)
	
		qui svy: reg fight abd $AC $ctrls if phase2==0
			outreg2 abd using "Data/Output/Civil War/table2.xls", br bdec(2) sdec(3) label nocons aster(se) replace
		qui svy: reg neighbor_trouble abd $AC $ctrls if phase2==1
			outreg2 abd using "Data/Output/Civil War/table2.xls", br bdec(2) sdec(3) label nocons aster(se)
		qui svy: reg antidemocratic abd $AC $ctrls if phase2==1
			outreg2 abd using "Data/Output/Civil War/table2.xls", br bdec(2) sdec(3) label nocons aster(se)
	
		foreach n of numlist 1 2 {
			foreach y of varlist educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted hostile  {
				qui svy: reg `y' abd abd_phase`n' $AC3 $ctrls
					outreg2 abd abd_phase`n' using "Data/Output/Civil War/table2.xls", br bdec(2) sdec(3) label nocons aster(se) 
				}
			}


//* Table 3: Reintegration Outcomes and War Experiences *//

	clear
	use "Data/tempdata/temp_all.dta"
	keep if abd==1 & found==1
	svyset [pweight=w_abs], strata(stratum) psu(camp)
	
	*Panel A
	
	qui svy, sub(if phase2==0): reg educ abd_lgth viol_personal viol_perp age age_2 age_3 C_* $ctrls
	 outreg2 abd_lgth viol_personal viol_perp using "Data/Output/Civil War/table3A.xls", br bdec(2) sdec(3) label nocons aster(se) replace
	
	foreach y of varlist educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted fight hostile {
	 qui svy, sub(if phase2==0): reg `y' abd_lgth viol_personal viol_perp force_wife bush_mom age age_2 age_3 C_* $ctrls
	  outreg2 abd_lgth viol_personal viol_perp using "Data/Output/Civil War/table3A.xls", br bdec(2) sdec(3) label nocons aster(se)
	}	
	
	*Panel B
	
	qui svy, sub(if phase2==1): reg educ abd_lgth viol_personal viol_perp age age_2 age_3 C_* $ctrls
	 outreg2 abd_lgth viol_personal viol_perp using "Data/Output/Civil War/table3B.xls", br bdec(3) label nocons aster(se) replace
	
	foreach y of varlist educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted hostile neighbor_trouble antidemocratic {
	 qui svy, sub(if phase2==1): reg `y' abd_lgth viol_personal viol_perp force_wife bush_mom age age_2 age_3 C_* $ctrls
	  outreg2 abd_lgth viol_personal viol_perp force_wife bush_mom using "Data/Output/Civil War/table3B.xls", br bdec(2) sdec(3) label nocons aster(se)
	}	
	
	*Panel C
	
	qui svy, sub(if phase2==1): reg educ abd_lgth viol_personal viol_perp age age_2 age_3 C_* $ctrls educ_abd inschool_abd
	 outreg2 abd_lgth viol_personal viol_perp using "Data/Output/Civil War/table3C.xls", br bdec(2) sdec(3) label nocons aster(se) replace
	
	foreach y of varlist educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted hostile neighbor_trouble antidemocratic {
	 qui svy, sub(if phase2==1): reg `y' abd_lgth viol_personal viol_perp force_wife bush_mom age age_2 age_3 C_* $ctrl educ_abd inschool_abd
	  outreg2 abd_lgth viol_personal viol_perp force_wife bush_mom educ_abd inschool_abd using "Data/Output/Civil War/table3C.xls", br bdec(2) sdec(3) label nocons aster(se)
	}	
		

//* Table 4: Average Impacts of Years Since Return (By Gender) *//

	use "Data/tempdata/temp_under30.dta", clear
	keep if abd==1 & found==1
	svyset [pweight=w_abs], strata(stratum) psu(camp)
	
	qui svy: reg educ back $ctrl $AC2 Y*
	outreg2 back using "Data/Output/Civil War/table4.xls", excel br bdec(2) sdec(3) label nocons aster(se) replace
	
	foreach y of varlist educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted fight hostile {
		qui svy, sub(if phase2==0): reg `y' back $ctrl $AC2 Y*
			outreg2 back using "Data/Output/Civil War/table4.xls", excel br bdec(2) sdec(3) label nocons aster(se)
	  	}	
	foreach y of varlist educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted hostile neighbor_trouble antidemocratic {
		qui svy, sub(if phase2==1): reg `y' back $ctrl $AC2 Y*
			outreg2 back using "Data/Output/Civil War/table4.xls", excel br bdec(2) sdec(3) label nocons aster(se) 
	  	}	
	


//* Table 5: Return Outcomes (For Youth Abducted More Than 2 Weeks) *//

	clear
	use "Data/tempdata/temp_all.dta"
	keep if abd==1 & twoweek==1
	svyset [pweight=w_abs], strata(stratum) psu(camp)
	
		clear
	use "Data/tempdata/temp_all.dta"
	keep if abd==1 & twoweek==1
	svyset [pweight=w_abs], strata(stratum) psu(camp)
	
//*Summary Statistics for columns (1) and (2) of table 5*//
	
	*Columns 1 and 2 - Male and Female sample means*
		cap matrix drop E
	
		global sumstatsT6 "ret_home ret_skool fam_prob_ever fam_prob_now fam_prob_better comm_prob_ever comm_prob_now comm_prob_better"
		
		*Female means
		foreach x in $sumstatsT6 {
		sum `x' if phase2==1 [iw=w_abs]
			sca c_mu2 = r(mean)
			sca c_sd2 = r(sd)
		
		*Male means
		sum `x' if phase2==0 [iw=w_abs]
			sca c_mu1 = r(mean)
			sca c_sd1 = r(sd)
	
			matrix E = nullmat(E)\(c_mu2, c_sd2, c_mu1, c_sd1)
			}

		local cnames `" "Mean (Females)" "Std. Dev. (Females)" "Mean (Males)" "Std. Dev. (Males)" "'
			local rname	
				
			foreach x in $sumstatsT6 {
				local lbl  `x'
				local rname `" `rname' `lbl' "'
			}	
		
			xml_tab E, save("Data/Output/Civil War/table5-sumstats.xls") replace noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 11) format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))

	* Column 3: Female - Male differences controlling for pre-war covariates
		* Reduced number of controls with dependent variables with few observations
			qui svy: reg ret_home phase2 age age_2 age_3 C_*
		   		outreg2 phase2 using "Data/Output/Civil War/table5.xls", br bdec(2) sdec(3) label nocons aster(se) replace 
			qui reg fam_prob_better phase2 age age_2 age_3 C_* [pw=w_abs], cluster(camp)
				outreg2 phase2 using "Data/Output/Civil War/table5.xls", br bdec(2) sdec(3) label nocons aster(se) 
			qui svy: reg comm_prob_better phase2 age age_2 age_3 C_*
		   		outreg2 phase2 using "Data/Output/Civil War/table5.xls", br bdec(2) sdec(3) label nocons aster(se) 	
	   
		* Full controls 
			foreach var of varlist ret_skool fam_prob_ever fam_prob_now comm_prob_ever comm_prob_now {
		   		qui svy: reg `var' phase2 age age_2 age_3 C_* fthr_ed mthr_ed no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow
			 		outreg2 phase2 using "Data/Output/Civil War/table5.xls", br bdec(2) sdec(3) label nocons aster(se) 
		  		}
	
	* Column 4: Female - Male differences controlling for pre-war covariates and abduction length and age of return
		* Reduced number of controls with dependent variables with few observations
			qui svy: reg ret_home phase2 age age_2 age_3 C_* abd_lgth age_back
		   		outreg2 phase2 using "Data/Output/Civil War/table5.xls", br bdec(2) sdec(3) label nocons aster(se) append 
			qui reg fam_prob_better phase2 age age_2 age_3 C_* abd_lgth age_back [pw=w_abs], cluster(camp)
				outreg2 phase2 using "Data/Output/Civil War/table5.xls", br bdec(2) sdec(3) label nocons aster(se) 
			qui svy: reg comm_prob_better phase2 age age_2 age_3 C_* abd_lgth age_back
		   		outreg2 phase2 using "Data/Output/Civil War/table5.xls", br bdec(2) sdec(3) label nocons aster(se) 	
	   
		* Full controls 
			foreach var of varlist ret_skool fam_prob_ever fam_prob_now comm_prob_ever comm_prob_now {
		   		qui svy: reg `var' phase2 age age_2 age_3 C_* fthr_ed mthr_ed no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow abd_lgth age_back
			 		outreg2 phase2 using "Data/Output/Civil War/table5.xls", excel br bdec(2) sdec(3) label nocons aster(se) 
		  		}


//* Table 6: Reinsertion Outcomes and War Experiences *//

	use "Data/tempdata/temp_all.dta", clear
	keep if abd==1 & twoweek==1
	svyset [pweight=w_abs], strata(stratum) psu(camp)
	
	* Panel A
	
	qui svy, sub(if phase2==0): reg ret_skool abd_lgth viol_personal viol_perp force_wife bush_mom age age_2 age_3 C_* $ctrls
		outreg2 abd_lgth viol_personal viol_perp using "Data/Output/Civil War/table6.xls", excel br bdec(2) sdec(3) label nocons aster(se) replace
	
	 foreach y of varlist ret_skool fam_prob_ever fam_prob_now comm_prob_ever comm_prob_now {
	 	qui svy, sub(if phase2==0): reg `y' abd_lgth viol_personal viol_perp age age_2 age_3 C_* $ctrls
	 		outreg2 abd_lgth viol_personal viol_perp using "Data/Output/Civil War/table6.xls", excel br bdec(2) sdec(3) label nocons aster(se) 
	 	}	
	
	* Panel B
	
	 foreach y of varlist ret_skool fam_prob_ever fam_prob_now comm_prob_ever comm_prob_now {
	  	qui svy, sub(if phase2==1): reg `y' abd_lgth viol_personal viol_perp force_wife bush_mom age educ_abd age_2 age_3 C_* $ctrls
	 		outreg2 abd_lgth viol_personal viol_perp force_wife bush_mom educ_abd using "Data/Output/Civil War/table6.xls", excel br bdec(2) sdec(3) label nocons aster(se) 
	  }	


//* Figure 1: Schooling by Age *//
   
	use "Data/tempdata/temp_all.dta", clear
	svyset [pweight=w_abs], strata(stratum) psu(camp)
	keep if found==1 & age<=30

	/* 1a: Probability Currently in School, by Current Age */ 
	
		running inschool age if phase2==0 & abd==0, ci span(1) gen(a1) nograph
		running inschool age if phase2==1 & abd==0, ci span(1) gen(a2) nograph
		sort age
		tw line a1 age if phase2==0 & abd==0 [pw=i_weight] , clc(maroon) || line a2 age if phase2==1 & abd==0 [pw=i_weight] , clc(blue) clpat(shortdash) xlab(14(2)30) ytitle("Currently in school", axis(1) size(medium) margin(right)) xtitle("Age", size(medlarge) margin(top)) graphr(color(white)) legend(label(1 "Males, 2005-06") label(2 "Females, 2007") r(1))
		drop a1 a2
	
	
	/* 1b: Educational Attainment, by Current Age */ 
	
		running educ age if phase2==0 & abd==0, ci span(1) gen(b1) nograph
		running educ age if phase2==1 & abd==0, ci span(1) gen(b2) nograph
		sort age
		tw line b1 age if phase2==0 & abd==0 [pw=i_weight], clc(maroon) || line b2 age if phase2==1 & abd==0 [pw=i_weight], clc(blue) clpat(shortdash) xlab(14(2)30) ytitle("Highest grade level attained", axis(1) size(medium) margin(right)) xtitle("Age", size(medlarge) margin(top)) graphr(color(white)) legend(label(1 "Males, 2005-06") label(2 "Females, 2007") r(1))
		drop b1 b2
	
	
	/* 1c: Probability returned to school after abduction, by age of abduction */
	
		running ret_skool age_back if age_back>=10 & phase2==0 & abd==1, ci span(1) gen(c1) nograph
		running ret_skool age_back if age_back>=10 & phase2==1 & bush_mom==0 & abd==1, ci span(1) gen(c2) nograph
		running ret_skool age_back if age_back>=10 & phase2==1 & bush_mom==1 & abd==1, ci span(1) gen(c3) nograph
		sort age_back
		tw line c1 age_back if age_back>=10 & phase2==0 & abd==1 [pw=i_weight], clc(maroon) || line c2 age_back if age_back>=10 & phase2==1 & abd==1 & bush_mom==0 [pw=i_weight], clc(blue) || line c3 age_back if age_back>=10 & phase2==1 & abd==1 & bush_mom==1 [pw=i_weight], clc(blue) clpat(shortdash) xlab(10(2)30) ytitle("Returned to School after Abduction", axis(1) size(medium) margin(right)) xtitle("Age Returned from Abduction", size(medlarge) margin(top)) graphr(color(white)) legend(label(1 "Males") label(2 "Females (non-mothers)") label(3 "Females (forced mothers)") r(2))
		drop c1 c2 c3



* 3) FIGURES AND ANALYSIS REPORTED IN PAPER BUT NOT INCLUDED IN TABLES

//* Table A: Summary statistics on abduction violence (All Respondents) *//
	
	use "Data/tempdata/temp_all.dta", clear

		cap matrix drop E
	
	global sumtableA "abd absentee died no_return nosurvive"
	global sumtableA2 "age viol_total viol_rec viol_wit viol_pers viol_perp viol_sex"
	
	foreach x in $sumtableA {
	sum `x' if phase2==1 [iw=i_weight]
		sca c_mu2 = r(mean)
		sca c_sd2 = r(sd)
		sca obs2 = r(N)
		
	sum `x' if phase2==0 [iw=i_weight]
		sca c_mu1 = r(mean)
		sca c_sd1 = r(sd)
		sca obs1 = r(N)
		
		matrix E = nullmat(E)\(c_mu2, c_sd2, obs2, c_mu1, c_sd1, obs1)
	}
	
	foreach x in $sumtableA2{
	sum `x' if phase2==1 [iw=w_abs]	
		sca c_mu2a = r(mean)
		sca c_sd2a = r(sd)
		sca obs2a = r(N)
		
	sum `x' if phase2==0 [iw=w_abs]
		sca c_mu1a = r(mean)
		sca c_sd1a = r(sd)
		sca obs1a = r(N)
		
		
	matrix E = nullmat(E)\(c_mu2a, c_sd2a, obs2a, c_mu1a, c_sd1a, obs1a)
	}


	local cnames `" "Mean (Females)" "Std. Dev. (Females)" "Obs. (Females)" "Mean (Males)" "Std. Dev. (Males)" "Obs. (Males)" "'
		local rname	
			
		foreach x in $sumtableA $sumtableA2{
			local lbl  `x'
			local rname `" `rname' `lbl' "'
		}	
		
		xml_tab E, save("Data/Output/Civil War/tableA.xls") replace noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 11) format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))



//* Table B: Summary statistics on abduction experiences (Abductees Only) *//
	
	use "Data/tempdata/temp_all.dta", clear
	
		
	global sumtableB "abd_age age_back abd_lgth escaped rescued released released_2w educ_abd inschool_abd emp_abd kill kill_sol harm_fam rewarded fighter stay safer loyal loyal_often lead orders force_wife bush_mom"
	global sumtableB2 "abd_age age_back abd_lgth escaped rescued released released_2w educ_abd inschool_abd emp_abd kill kill_sol harm_fam rewarded gun gun_keep stay safer loyal loyal_often lead orders force_wife bush_mom"
	
	cap matrix drop E
	
	foreach x in $sumtableB {
	sum `x' if phase2==1 & abd==1 [iw=w_abs]
		sca c_mu = r(mean)
		sca c_sd = r(sd)
		sca obs = r(N)
		
	sum `x' if phase2==1 & abd==1 & twoweek==1 [iw=w_abs]
		sca c_mu1 = r(mean)
		sca c_sd1 = r(sd)
		sca obs1 = r(N)
		
		matrix E = nullmat(E)\(c_mu, c_sd, obs, c_mu1, c_sd1, obs1)
	}
	
	foreach x in $sumtableB2 {
	sum `x' if phase2==0 & abd==1 [iw=w_abs]
		sca c_mu2 = r(mean)
		sca c_sd2 = r(sd)
		sca obs2 = r(N)
		
	sum `x' if phase2==0 & abd==1 & twoweek==1 [iw=w_abs]
		sca c_mu3 = r(mean)
		sca c_sd3 = r(sd)
		sca obs3 = r(N)
		
		matrix E = nullmat(E)\(c_mu2, c_sd2, obs2, c_mu3, c_sd3, obs3)
	}
	
		local cnames `" "Mean" "Std. Dev." "Obs." "Mean (Abd > two weeks)" "Std. Dev. (Abd > two weeks)" "Obs. (Abd > two weeks)" "'
		local rname	
			
		foreach x in $sumtableB $sumtableB2{
			local lbl  `x'
			local rname `" `rname' `lbl' "'
		}	
		
		xml_tab E, save("Data/Output/Civil War/tableB.xls") replace noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 11) format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))
	
	

//* Table C: Summary statistics on outcomes (All respondents) *//

	use "Data/tempdata/temp_all.dta", clear
	
	global sumtableC "educ injury aindex wage_mo prof emp_mo emp_d_mo support fam_connect group distress distress75 blame_haunted fight hostile neighbor_trouble antidemocratic"
	
	cap matrix drop E
	
	foreach x in $sumtableC {
	sum `x' if phase2==1 [iw=w_abs]
		sca c_mu = r(mean)
		sca c_sd = r(sd)
		sca obs = r(N)
		
	sum `x' if phase2==0 [iw=w_abs]
		sca c_mu1 = r(mean)
		sca c_sd1 = r(sd)
		sca obs1 = r(N)
		
		matrix E = nullmat(E)\(c_mu, c_sd, obs, c_mu1, c_sd1, obs1)
	}
	
	
		local cnames `" "Mean (Females)" "Std. Dev. (Females)" "Obs. (Females)" "Mean (Males)" "Std. Dev. (Males)" "Obs. (Males)" "'
		local rname	
			
		foreach x in $sumtableC {
			local lbl  `x'
			local rname `" `rname' `lbl' "'
		}	
		
		xml_tab E, save("Data/Output/Civil War/tableC.xls") replace noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 11) format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))



* 4) Other statistics quoted in the Paper but not in Tables

	clear
	use "Data/tempdata/temp_all.dta"
	svyset [pweight=w_abs], strata(stratum) psu(camp)
	
	keep if age>=14 & age <=35
	
	summ viol_sex if abd==0 & phase2==1
	
	keep if found==1
	keep if abd==1
	
	summ abd_lgth if phase2==1 [iw=w_abs]
	summ abd_lgth if phase2==0 [iw=w_abs]
	summ twoweek if phase2==1 [iw=w_abs]
	summ abd_lgth if phase2==1 & abd_lgth>=1 [iw=w_abs]
	di 69/613
	summ gun if phase2==0 [iw=w_abs]
	summ viol_perp if phase2==1 [iw=w_abs]
	summ viol_perp if phase2==0 [iw=w_abs]
	summ force_wife if phase2==1 & twoweek==1 [iw=w_abs]
	summ viol_sex if force_wife==1 & phase2==1 [iw=w_abs]
	summ viol_sex if force_wife==0 & phase2==1 [iw=w_abs]
	summ force_wife_months if phase2==1 [iw=w_abs]
	svy: reg force_wife_months educ age age_2 age_3 C_*
	summ released_2w if phase2==1 [iw=w_abs]
	summ released_2w if phase2==0 [iw=w_abs]
	summ reception [iw=w_abs]
	summ elders_disobey if phase2==1 [iw=w_abs]
	summ elders_disobey if phase2==0 [iw=w_abs]


