/*
DATA ANALYSIS FILE FOR "CONSEQUENCES OF CHILD SOLDIERING" BY BLATTMAN & ANNAN (2010)
JUNE 2013
STATA 12 CODE

NOTES:
	Full replication materials for the entire Survey of War Affected Youth (SWAY) 
	and all associated papers, including a data manual and full original surveys, 
	are available at http://chrisblattman.com

INSTRUCTIONS FOR THIS DO FILE
	1. Copy the full replication folder to your computer 
	2. Update the link below to point to the replication folder on your computer.
	3. All results will be saved in your replication folder under Data/Output/Consequences.
	
TABLE OF CONTENTS
	1. Data preparation
	2. Analysis
		TABLES:
		a. Table 1: Description of key variables
		b. Table 2: Comparison of Means
		c. Table 3: Estimates of the average treatment effect of abduction
		d. Table 4: Spillover effects of abduction intensity
		e. Table 5: Variation in the average treatment effect by age of abduction
		f. Table 6: Treatment effect bounding for selective attrition
		g. Table 7: Estimates of the impact of abduction length and violence on outcomes
		h. Table 8: Correlates of wages and the decomposition of wage ATE
		i. Table A1: Education and wealth differences between non-abducted Acholi and other Ugandan youth
		FIGURES:
		a. Figure 2: Distribution of abductions by age at the time of abduction
		b. Figure 3: Distribution of the predicted probability of abduction
		c. Figure 4: Quantile difference in the distribution of psychological distress between abducted and nonabducted youth
		d. Figure 5: Impact of relaxing the assumption of unconfoundedness
*/

// Set up data set
   clear
   set mem 40m
   set matsize 400
   set more off
   cap log close
   ssc install margeff, replace
   
cd "YOUR DIRECTORY\SWAY.Replication.June2013"


* 1) DATA PREPARATION

// SORT DATASETS //

   use Data/par_grp, clear
   sort camp parish
   save Data/par_grp, replace
   
   use Data/abd_risk, clear
   sort par_grp age
   save Data/abd_risk, replace
   
   use Data/abn_risk_total, clear
   sort par_grp
   save Data/abn_risk_total, replace

	use Data/SWAY_I_June2013.dta, clear

// Create global macros
   global depvar1 "literate emp_mo prof distress75 hostile fight"
   global depvar2 "educ lwage_mo distress support"
   global AC "A14-A29 C_ach-C_paj" 
   global ACG "A14-A29 C_ach-C_paj G1_18-G1_22 G2_14 G2_22 G3_14-G3_18 G4_14-G4_22 G5_14-G5_22 G6_14-G6_22 G7_14-G7_22 G8_14-G8_22" 
   global ctrls "fthr_ed0 fthr_ed4 fthr_ed7 mthr_ed0 mthr_ed4 mthr_ed7 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_size96_2 hh_size96_3 hh_size96_4 hh_land hh_land_2 hh_land_3 hh_land_4 hh_cattle hh_cattle_2 hh_cattle_3 hh_cattle_4 hh_stock hh_stock_2 hh_stock_3 hh_stock_4 hh_plow"
   global ctrl_hh "age hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow"
   global ctrl_i "fthr_ed0 fthr_ed mthr_ed0 mthr_ed no_fthr96 no_mthr96 orphan96"

// Create new variables
   gen abd2w=cond(abd==1 & abd_lgth>.5,1,0)
   gen landrich=cond(hh_land>=50 & hh_land!=.,1,0)
   gen distress75=cond(distress>5,1,0) if found==1
   gen distress90=cond(distress>=7,1,0) if found==1
   gen quarrel=viii13/3
   gen steal=viii18/3
   gen curse=viii25/3
   gen threaten=viii30/3
   gen hostile2=cond(steal>0 | threaten>0 | quarrel>0,1,0) if found==1
   gen mphone=cond(ii18k>0 & ii18k!=.,1,0)
   gen radio=cond(ii18e>0 & ii18e!=.,1,0)
   gen bike=cond(ii18c>0 & ii18c!=.,1,0)
   gen lwage_mo = ln(wage_mo)
   gen town_out_dist = cond(town==1 & out_dist==1,1,0)

   foreach var of varlist age hh_size96 hh_land landrich hh_cattle hh_stock hh_plow {
    gen `var'_2 = `var'^2
    gen `var'_3 = `var'^3
    gen `var'_4 = `var'^4
     }

   replace abd_l=abd_l/12

// Create selection weights for use with abducted youth only

   drop pscore*
	logit abd $AC $ctrls [pw=w_abs2]
		predict pscore if found==1
	gen z=w_abs2/pscore if abd==1 & found==1
	egen sumz=sum(z) if found==1
      egen sumi=sum(i_weight)
	gen w_abd=(z*sumi/sumz) if found==1
	drop z sumz sumi

   save Data/tempdata/consequences_temp.dta, replace
   

* 2) ANALYSIS

// Table 1: Description of key variables

   summ abd abd2w [iw=i_weight]
   summ abd_l abd_age if abd==1 & found==1 [iw=w_abs2]
   summ viol_perp viol_exper $depvar1 $depvar2 wage_mo if found==1 [iw=w_abs2]
   summ viol_perp viol_exper $depvar1 $depvar2 wage_mo if found==1 & abd==1 [iw=w_abs2]
   summ viol_perp viol_exper $depvar1 $depvar2 wage_mo if found==1 & abd==0 [iw=w_abs2]

   tab viii36 [iw=w_abs2]
   tab viii42 [iw=w_abs2]
   tab viii43 [iw=w_abs2]
   tab viii44 [iw=w_abs2]
   tab haunted [iw=w_abs2]

// Table 2: Comparison of Means (Abducted versus Non-abducted), (Militia/army versus non-militia/army)

   log using "Data/Output/Consequences/table2a.txt",replace t

   svyset [pw=i_weight], strata(stratum) psu(camp)

   svy: mean age $ctrl_hh, subpop(abd) 
   svy: mean age $ctrl_hh, subpop(nonabd) 
   svy: mean age $ctrl_hh, over(abd) 
   lincom [age]1 - [age]0
   lincom [hh_fthr_frm]1 - [hh_fthr_frm]0
   lincom [hh_size96]1 - [hh_size96]0
   lincom [hh_land]1 - [hh_land]0
   lincom [landrich]1 - [landrich]0
   lincom [hh_cattle]1 - [hh_cattle]0
   lincom [hh_stock]1 - [hh_stock]0
   lincom [hh_plow]1 - [hh_plow]0 

   keep if found==1

   svyset [pw=w_abs2], strata(stratum) psu(camp)

   svy: mean $ctrl_i, subpop(abd) 
   svy: mean $ctrl_i, subpop(nonabd) 
   svy: mean $ctrl_i, over(abd) 
   lincom [fthr_ed0]1 - [fthr_ed0]0
   lincom [fthr_ed]1 - [fthr_ed]0
   lincom [mthr_ed0]1 - [mthr_ed0]0
   lincom [mthr_ed]1 - [mthr_ed]0
   lincom [no_fthr96]1 - [no_fthr96]0
   lincom [no_mthr96]1 - [no_mthr96]0
   lincom [orphan96]1 - [orphan96]0

   log close

   qui svy: reg age abd C_ach-C_paj fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se replace
   qui svy: reg hh_fthr_frm abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg hh_size96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg hh_land abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg landrich abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg hh_cattle abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg hh_stock abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg hh_plow abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock   
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg fthr_ed0 abd $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg fthr_ed abd $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg mthr_ed0 abd $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg mthr_ed abd $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg no_fthr96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg no_mthr96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append
   qui svy: reg orphan96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg abd using "Data/Output/Consequences/table2b.txt", bdec(2) br se append


   log using "Data/Output/Consequences/table2c.txt",replace t

   svy: mean age $ctrl_hh $ctrl_i, subpop(army) 
   svy: mean age $ctrl_hh $ctrl_i, subpop(noarmy) 
   svy: mean age $ctrl_hh $ctrl_i, over(army) 
   lincom [age]1 - [age]0
   lincom [hh_fthr_frm]1 - [hh_fthr_frm]0
   lincom [hh_size96]1 - [hh_size96]0
   lincom [hh_land]1 - [hh_land]0
   lincom [landrich]1 - [landrich]0
   lincom [hh_cattle]1 - [hh_cattle]0
   lincom [hh_stock]1 - [hh_stock]0
   lincom [hh_plow]1 - [hh_plow]0 
   lincom [fthr_ed0]1 - [fthr_ed0]0
   lincom [fthr_ed]1 - [fthr_ed]0
   lincom [mthr_ed0]1 - [mthr_ed0]0
   lincom [mthr_ed]1 - [mthr_ed]0
   lincom [no_fthr96]1 - [no_fthr96]0
   lincom [no_mthr96]1 - [no_mthr96]0
   lincom [orphan96]1 - [orphan96]0

   log close

   qui svy: reg age army C_ach-C_paj fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se replace
   qui svy: reg hh_fthr_frm army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg hh_size96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg hh_land army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg landrich army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg hh_cattle army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg hh_stock army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg hh_plow army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock   
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg fthr_ed0 army $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg fthr_ed army $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg mthr_ed0 army $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg mthr_ed army $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg no_fthr96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg no_mthr96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 orphan96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append
   qui svy: reg orphan96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 hh_fthr_frm hh_size96 hh_land landrich hh_cattle hh_stock hh_plow
	outreg army using "Data/Output/Consequences/table2d.txt", bdec(2) br se append


// Table 3: Estimates of the average treatment effect of abduction (using WLS)

      svyset [pw=w_sel_abs], strata(stratum) psu(camp)

      qui svy: reg wage_mo $ctrls $ACG abd
      outreg abd using "Data/Output/Consequences/table3.out", se br replace bdec(2)
   	   foreach y of varlist literate emp_mo {
		qui svy: logit `y' abd $AC $ctrls
		qui margeff, r 
		outreg abd using "Data/Output/Consequences/table3.out", se br append bdec(2)
		}	
	   foreach y of varlist prof distress75 hostile fight {
                qui svy: logit `y' abd age age_2 age_3 C_ach-C_paj $ctrls
		qui margeff, r 
		outreg abd using "Data/Output/Consequences/table3.out", se br append bdec(2)
		}
   	   foreach y of varlist $depvar2 {
		qui svy: reg `y' abd $ACG $ctrls
		outreg abd using "Data/Output/Consequences/table3.out", se br append bdec(2)
		}	

// Table 4: Spillover effects of abduction intensity


* Merge in aggregate abduction risk

   sort camp parish 
   merge camp parish using Data/par_grp
   drop if _merge==2
   drop _merge 

   sort par_grp age
   merge par_grp age using Data/abd_risk
   drop if _merge==2
   drop _merge

   sort par_grp
   merge par_grp using Data/abn_risk_total
   drop _merge 

   sort camp parish age
   replace abd_risk=abd_risk*100
   replace p_risk =p_risk *100
   replace c_risk=c_risk*100

	svyset [pw=i_weight], strata(stratum) psu(camp)
	qui svy: reg town p_risk $AC $ctrls if abd==0 
	  outreg p_risk using "Data/Output/Consequences/table4.txt", bdec(2) br se replace
	qui svy: reg out_dist p_risk $AC $ctrls if abd==0 
	  outreg p_risk using "Data/Output/Consequences/table4.txt", bdec(2) br se append
	qui svy: reg town_out_dist p_risk $AC $ctrls if abd==0 
	  outreg p_risk using "Data/Output/Consequences/table4.txt", bdec(2) br se append
	
	svyset [pw=w_abs2], strata(stratum) psu(camp)
	foreach y of varlist educ literate emp_mo prof lwage_mo distress distress75 support hostile fight {
	  qui svy: reg `y' p_risk $AC $ctrls if abd==0 & found==1
	  outreg p_risk using "Data/Output/Consequences/table4.txt", bdec(2) br se append
	  } 
	

// Table 5: Variation in the average treatment effect by age of abduction

   svyset [pw=w_abd], strata(stratum) psu(camp)

   qui svy: reg wage_mo abd_age $AC $ctrls
   outreg abd_age using "Data/Output/Consequences/table5.out", se br replace
   foreach y in literate emp_mo distress75 {
	qui svy: logit `y' abd_age $AC $ctrls
	qui margeff, r 
	outreg abd_age using "Data/Output/Consequences/table5.out", se br append bdec(2)
	}
    foreach y in prof hostile fight {
	qui svy: logit `y' abd_age $AC hh_size96 hh_wealth96 fthr_ed mthr_ed
	/* qui margeff, r */
	outreg abd_age using "Data/Output/Consequences/table5.out", se br append bdec(2)
	}
   foreach y in $depvar2 {
	qui svy: reg `y' abd_age $AC $ctrls
	outreg abd_age using "Data/Output/Consequences/table5.out", se br append bdec(2)
	}

// Table 6: Treatment effect bounding for selective attrition (ATE bounds)

   use Data/tempdata/consequences_temp.dta, clear
   gen randvar=uniform()

   foreach y of varlist educ literate emp_mo {
      replace `y'=. if sample==0
      }
   foreach y of varlist lwage_mo distress support prof distress75 hostile fight {
      replace `y'=. if found==0
      }

   do "trimbound"

   log using "Data/Output/Consequences/table6.txt",replace t
      foreach y of varlist $depvar1 $depvar2 {
   	   trimbound `y' abd i_weight randvar
	   }
   log close


// Table 7: Estimates of the impact of abduction length and violence on outcomes

   use Data/tempdata/consequences_temp.dta, clear
   keep if found==1

   svyset [pw=w_abd], strata(stratum) psu(camp)

   qui svy: reg wage_mo viol_personal viol_perp abd_l $AC $ctrls if abd==1
   outreg viol_personal viol_perp abd_l using "Data/Output/Consequences/table7.out", se br bdec(3) replace
	foreach y in literate emp_mo distress75 {
		qui svy: logit `y' viol_personal viol_perp abd_l $AC $ctrls if abd==1
		qui margeff, r 
			outreg viol_personal viol_perp abd_l using "Data/Output/Consequences/table7.out", se br bdec(3) append
		}
	foreach y in prof hostile fight {
		qui svy: logit `y' viol_personal viol_perp abd_l age age_2 age_3 C_ach-C_paj hh_size96 hh_wealth96 fthr_ed mthr_ed if abd==1
		qui margeff, r 
			outreg viol_personal viol_perp abd_l using "Data/Output/Consequences/table7.out", se br bdec(3) append
		}

	foreach y in $depvar2 {
		qui svy: reg `y' viol_personal viol_perp abd_l $AC $ctrls if abd==1
			outreg viol_personal viol_perp abd_l using "Data/Output/Consequences/table7.out", se br bdec(3) append
		}


// Table 8: Correlates of wages and the decomposition of wage ATE

   svyset [pw=w_abs2], strata(stratum) psu(camp)

   qui svy: reg lwage_mo educ exper support injury distress 
	outreg using "Data/Output/Consequences/table8.out", se br replace bdec(2)



// Table A1: Education and wealth differences between non-abducted Acholi and other Ugandan youth



   keep id2 id inschool educ illiterate age hhsize bike radio mphone i_weight w_abs2 found absent abd town

   append using Data\nat_surv.dta

   gen central=cond(region==1,1,0)
   gen eastern=cond(region==2,1,0)
   gen northern=cond(region==3,1,0)
   gen western=cond(region==4,1,0)
   gen acholi=cond(region==.,1,0)

   replace urban=0 if acholi==1
   replace urban=1 if town==1
   replace abd=0 if acholi==0
   replace educ=15 if educ>15 & educ!=.

   tab age, g(A)

   gen W=w_abs2 if found==1
   replace W=i_w if found==.

   summ educ inschool illiterate mphone bike radio [iw=W] if found==1 & abd==0

   qui reg educ northern central eastern western A1-A16 [iw=W] if abd==0
	outreg northern central eastern western using "Data/Output/Consequences/tableA1.txt", bdec(2) br se replace
   qui logit inschool northern central eastern western A1-A16 [iw=W] if abd==0
      qui margeff, r 
	outreg northern central eastern western using "Data/Output/Consequences/tableA1.txt", bdec(2) br se append
   qui logit illiterate northern central eastern western A1-A16 [iw=W] if abd==0
      qui margeff, r 
	outreg northern central eastern western using "Data/Output/Consequences/tableA1.txt", bdec(2) br se append
   qui logit mphone northern central eastern western A1-A16 [iw=W] if abd==0
      qui margeff, r 
	outreg northern central eastern western using "Data/Output/Consequences/tableA1.txt", bdec(2) br se append
   qui logit bike northern central eastern western A1-A16 [iw=W] if abd==0
      qui margeff, r 
	outreg northern central eastern western using "Data/Output/Consequences/tableA1.txt", bdec(2) br se append
   qui logit radio northern central eastern western A1-A16 [iw=W] if abd==0
      qui margeff, r
	outreg northern central eastern western using "Data/Output/Consequences/tableA1.txt", bdec(2) br se append


// Figure 2: Distribution of abductions by age at the time of abduction

   use Data/tempdata/consequences_temp.dta, clear
   tw hist abd_age if abd==1 & abd_age>=5 [fw=f_weight], start(5) xlab(5(2)30) percent bc(gs5) blc(white) xtitle("Age of Longest Abduction", margin(top) size(medlarge)) ytitle("Percent", margin(right) size(medlarge)) legend(off) graphr(color(white))


// Figure 3: Distribution of the predicted probability of abduction (propensity scores)

   use Data/tempdata/consequences_temp.dta, clear
   svyset [pw=w_abs2], strata(stratum) psu(camp)

   drop pscore*
   svy: logit abd $ACG
	predict pscore
   svy: logit abd $ACG $ctrls
	predict pscore2

   label define abdn 0 "Non-Abducted" 1 "Abducted"
   label values abd abdn

   twoway histogram pscore, width(.05) gap(10) bcolor(gs5) percent start(0) || histogram pscore2, graphr(color(white)) width(.05) percent start(0) xlab(0(.1)1) gap(50) xtitle("Predicted Probability of Abduction", margin(top)) ytitle("% of Respondents", margin(left)) legend(label(1 "Age & location dummies only") label(2 "All pre-treatment covariates")) by(abd, note("") graphr(color(white))) xsize(5) ysize(3) 


// Figure 4: Quantile difference in the distribution of psychological distress between abducted and nonabducted youth

* Note: The file figure4.csv is needed to replicate Figure 5. This data is available upon request.

   use Data/tempdata/consequences_temp.dta, clear
   keep if found==1

   qreg distress abd age age_2 age_3 C_ach-C_paj hh_size96 hh_wealth96 fthr_ed mthr_ed, q(90)
		outreg abd using Data/Output/Consequences/figure4, replace br 3aster se
   qreg distress abd age age_2 age_3 C_ach-C_paj hh_size96 hh_wealth96 fthr_ed mthr_ed, q(50)
		outreg abd using Data/Output/Consequences/figure4, append br 3aster se
		foreach n of numlist 1/99 {
			qreg distress abd age age_2 age_3 C_ach-C_paj hh_size96 hh_wealth96 fthr_ed mthr_ed, nolog q(`n')
				outreg abd using Data/Output/Consequences/figure4, append se nopa noas
			}
	/*
	insheet using "C:\Documents and Settings\cb526\My Documents\Research\Consequences\stata\figure4.csv", comma clear names
	gen quantile=_n 
	gen upbound=qte+1.96*se 
	gen lobound=qte-1.96*se 
	tw line qte quantile if quantile<98 , clc(maroon) clw(medthick) || line upbound quantile if quantile<98 & upbound<2, clc(maroon) clpat(shortdash) || line lobound quantile if quantile<98 & lobound>-1, clc(maroon) clpat(shortdash) xlab(0(10)100) ylab(-1(.5)2) yline(0, lc(black)) xti("Quantile", margin(top) size(medlarge)) yti("Difference in CDFs by abduction", margin(right) size(medlarge)) legend(r(1) label(1 "Difference in CDFs") label(2 "95% upper CI") label(3 "95% lower CI") size(small)) graphr(color(white))


// Figure 5: Impact of relaxing the assumption of unconfoundedness

* Note: The file figure5.csv is needed to replicate Figure 5. This data is available upon request.

   insheet using "C:\Documents and Settings\cb526\My Documents\Research\Consequences\stata\figure5.csv", comma clear names
   gen n=_n
   gen v=""
   replace v=var if _n==2 | _n==3 | _n==6 | _n==7 | _n==8 | _n==9 | _n==10 
   tw fpfit ryp rwp if n>10, clpat(dash) || scatter ryp rwp if n<=10, m(+) ml(v) mc(black) yti("Influence of covariate on education" "(Increase in R-squared)", margin(right) size(medium)) xti("Influence of covariate on abduction" "(Increase in R-squared)", margin(top) size(medium))  graphr(color(white)) legend(r(2) label(1 "Threshold for binomial covariate to reduce education ATE by half") label(2 "Influence of pre-war covariates on education and abduction") size(small)) ysize(5) xsize(6.5)
