/*
DATA ANALYSIS FILE FOR "FROM VIOLENCE TO VOTING" BY BLATTMAN (2009)
JUNE 2013
STATA 12 CODE

NOTES:
	Full replication materials for the entire Survey of War Affected Youth (SWAY) 
	and all associated papers, including a data manual and full original surveys, 
	are available at http://chrisblattman.com

INSTRUCTIONS FOR THIS DO FILE
	1. Copy the full replication folder to your computer 
	2. Update the link below to point to the replication folder on your computer.
	3. All results will be saved in your replication folder under Data/Output/Violence.

TABLE OF CONTENTS
	1. Data preparation
	2. Analysis
		TABELS:
		a. Table 1: Summary Statistics
		b. Table 2: Determinants of LRA Abduction and Recruitment into Government Militias
		c. Table 3: Impact of Abduction on Social and Political Participation
		d. Table 4: Impact of War Experiences (Former Abductees Only)
		e. Table 5: Impact of War Experiences on Participation (All Respondents)
		f. Table 6: Relative Explanatory Power of the Correlates of Participation
		FIGURES:
		a. Figure 1: Impact of Relaxing the Assumption of Unconfoundedness
*/

cd "YOUR DIRECTORY\SWAY.Replication.June2013"

// Set up dataset

clear
set mem 30m
set matsize 800
set more off
version 9.2
cap log close
ssc install margeff, replace
ssc install outreg2, replace

use Data/SWAY_I_June2013.dta, clear

* 1) DATA PREPARATION

	// Set up globals
	
	global G "A14-A29 C_ach-C_paj G1_14_17 G1_18_21 G1_22_25 G1_26_30 G2_14_17 G2_18_21 G2_22_25 G2_26_30 G3_14_17 G3_18_21 G3_22_25 G3_26_30 G4_14_17 G4_18_21 G4_22_25 G4_26_30 G5_14_17 G5_18_21 G5_22_25 G5_26_30 G6_14_17 G6_18_21 G6_22_25 G6_26_30 G7_14_17 G7_18_21 G7_22_25 G7_26_30 G8_14_17 G8_18_21 G8_22_25 G8_26_30"
	global D "age age2 age3 C_ach-C_paj" 
	global ctrl_short "fthr_ed mthr_ed hh_size96 hh_wealth96"
	global ctrl "fthr_ed fthr_ed0 mthr_ed mthr_ed0 no_fthr96 no_mthr96 hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow"
	global ctrls "fthr_ed0 fthr_ed7 fthr_edhi mthr_ed0 mthr_ed7 mthr_edhi no_fthr96 no_mthr96 hh_fthr_frm hh_size96 hh_size962 hh_size963 hh_size964 hh_land hh_land2 hh_land3 hh_land4 hh_cattle hh_cattle2 hh_cattle3 hh_cattle4 hh_stock hh_stock2 hh_stock3 hh_stock4 hh_plow"
	global covars "town out_dist injury distress75 asset_ind emp_d_mo earn_mo volunteer asocial75 support literate radio educ"
	global depvars "vote05 comm_mobil group g_peace g_water g_drama g_sport g_farm g_skool g_church church volunteer elders_disobey asocial75 fight"
	global depvars2 "quarrel threaten"
	global warexp "viol_witnessed viol_loss viol_received viol_perp labd_lgth gun_keep leader reception services"
	global ctrl_hh "age hh_fthr_frm hh_size96 hh_land hh_cattle hh_stock hh_plow"
	global ctrl_i "fthr_ed0 fthr_ed mthr_ed0 mthr_ed no_fthr96 no_mthr96 orphan96"

	// Create new variables
	
	foreach var of varlist age hh_size96 hh_land hh_cattle hh_stock {
	   gen `var'2=`var'^2
	   gen `var'3=`var'^3
	   gen `var'4=`var'^4
	   }
	
	gen asocial75=cond(prosocial<3.5,1,0)
	
	gen distress75=cond(distress>5,1,0)
	
	egen asset_ind=std(aindex)
	
	replace reception=0 if reception==. & abd==1
	
	gen labd_l = ln(abd_l)
	gen labd_lgth = ln(abd_lgth)
	
	gen quarrelsome=cond(viii13>0,1,0)
	gen curse=cond(viii25>0,1,0)
	gen threaten=cond(viii30>0,1,0)
	
	gen radio=cond(ii18e>=1,1,0)
	
	drop services
	gen services=cond(ix781==1 | ix782==1 | ix783==1 | ix785==1 | ix786==1 | ix787==1,1,0)
	replace services=. if abd==0
	
	replace leader=0 if leader==. & abd==1
	replace gun_keep=0 if gun_keep==. & abd==1
	
	gen kitgum=cond(district==1,1,0)


	// Set survey weights, strata and clustering
	
	svyset [pweight=w_sel_abs], strata(stratum) psu(camp)
	

* 2) ANALYSIS

// Table and Figures

* Table 1: Summary Statistics

cap matrix drop E
		
		gl warexpt1 "abd_lgth abd_age viol_total viol_witnessed viol_loss viol_received viol_perp leader gun_keep reception services"
		gl socpolt1 "vote05 comm_mobil pol_job group g_peace g_water g_drama g_sport g_farm g_skool g_church church volunteer elders_d asocial75 fight quarrel threaten"
		
	//War experiences	
		foreach x in $warexp {
	 	sum `x' [iw=w_abs2] if found==1
				sca c_mu_e = r(mean)
				sca c_v_e = r(sd)
				sca obs_e = r(N)
				
		sum `x' if abd==1 & found==1 [iw=w_abs2]
				sca c_mu_e3 = r(mean)
				sca c_v_e3 = r(sd)
				
		sum `x' if abd==0 & found==1 [iw=w_abs2]
				sca c_mu_e2 = r(mean)
				sca c_v_e2 = r(sd)
			
		 		
			matrix E = nullmat(E)\(c_mu_e, c_v_e, c_mu_e2, c_v_e2, c_mu_e3, c_v_e3, obs_e)
		}	
		
	//Social and political variables
		foreach x in $socpol {
		 sum `x' [iw=w_abs2] if found==1
				sca c_mu_e = r(mean)
				sca c_v_e = r(sd)
				sca obs_e = r(N)
				
		sum `x' [iw=w_abs2] if abd==1 & found==1
				sca c_mu_e3 = r(mean)
				sca c_v_e3 = r(sd)
				
		sum `x' [iw=w_abs2] if abd==0 & found==1
				sca c_mu_e2 = r(mean)
				sca c_v_e2 = r(sd)
				
			matrix E = nullmat(E)\(c_mu_e, c_v_e, c_mu_e2, c_v_e2, c_mu_e3, c_v_e3, obs_e)
		
		}
			
			
		local cnames `" "Mean" "Std. Dev." "Mean" "Std. Dev." "Mean" "Std. Dev." "Obs""'
		local rname	
			
		foreach x in $warexp $socpol {
			local lbl  `x'
			local rname `" `rname' `lbl' "'
		}	
		
		xml_tab E, save("Data/Output/Violence/table1.xls") replace noisily cnames(`cnames') rnames(`rname') font("Times New Roman" 11) format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))



* Table 2: Determinants of LRA Abduction and Recruitment into Government Militias

   log using "Data/Output/Violence/table2a.txt",replace t

   svyset [pw=i_weight], strata(stratum) psu(camp)

   svy: mean age $ctrl_hh, subpop(abd) 
   svy: mean age $ctrl_hh, subpop(nonabd) 
   svy: mean age $ctrl_hh, over(abd) 
   lincom [age]1 - [age]0
   lincom [hh_fthr_frm]1 - [hh_fthr_frm]0
   lincom [hh_size96]1 - [hh_size96]0
   lincom [hh_land]1 - [hh_land]0
 
   lincom [hh_cattle]1 - [hh_cattle]0
   lincom [hh_stock]1 - [hh_stock]0
   lincom [hh_plow]1 - [hh_plow]0 

   keep if found==1

   svyset [pw=w_abs2], strata(stratum) psu(camp)

   svy: mean $ctrl_i, subpop(abd) 
   svy: mean $ctrl_i, subpop(nonabd) 
   svy: mean $ctrl_i, over(abd) 
   lincom [fthr_ed0]1 - [fthr_ed0]0
   lincom [fthr_ed]1 - [fthr_ed]0
   lincom [mthr_ed0]1 - [mthr_ed0]0
   lincom [mthr_ed]1 - [mthr_ed]0
   lincom [no_fthr96]1 - [no_fthr96]0
   lincom [no_mthr96]1 - [no_mthr96]0
   lincom [orphan96]1 - [orphan96]0

   log close

   qui svy: reg age abd C_ach-C_paj fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se replace
   qui svy: reg hh_fthr_frm abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg hh_size96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg hh_land abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg hh_cattle abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg hh_stock abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg hh_plow abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock   
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg fthr_ed0 abd $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg fthr_ed abd $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg mthr_ed0 abd $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg mthr_ed abd $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg no_fthr96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg no_mthr96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append
   qui svy: reg orphan96 abd $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 abd using "Data/Output/Violence/table2b.txt", bdec(2) br se append

   log using "Data/Output/Violence/table2c.txt",replace t

   svy: mean age $ctrl_hh $ctrl_i, subpop(army) 
   svy: mean age $ctrl_hh $ctrl_i, subpop(noarmy) 
   svy: mean age $ctrl_hh $ctrl_i, over(army) 
   lincom [age]1 - [age]0
   lincom [hh_fthr_frm]1 - [hh_fthr_frm]0
   lincom [hh_size96]1 - [hh_size96]0
   lincom [hh_land]1 - [hh_land]0
   lincom [hh_cattle]1 - [hh_cattle]0
   lincom [hh_stock]1 - [hh_stock]0
   lincom [hh_plow]1 - [hh_plow]0 
   lincom [fthr_ed0]1 - [fthr_ed0]0
   lincom [fthr_ed]1 - [fthr_ed]0
   lincom [mthr_ed0]1 - [mthr_ed0]0
   lincom [mthr_ed]1 - [mthr_ed]0
   lincom [no_fthr96]1 - [no_fthr96]0
   lincom [no_mthr96]1 - [no_mthr96]0
   lincom [orphan96]1 - [orphan96]0

   log close

   qui svy: reg age army C_ach-C_paj fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se replace
   qui svy: reg hh_fthr_frm army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg hh_size96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg hh_land army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg hh_cattle army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg hh_stock army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg hh_plow army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock   
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg fthr_ed0 army $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg fthr_ed army $ACG mthr_ed mthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg mthr_ed0 army $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg mthr_ed army $ACG fthr_ed fthr_ed0 no_fthr96 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg no_fthr96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_mthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg no_mthr96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 orphan96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append
   qui svy: reg orphan96 army $ACG fthr_ed mthr_ed fthr_ed0 mthr_ed0 no_fthr96 no_mthr96 hh_fthr_frm hh_size96 hh_land  hh_cattle hh_stock hh_plow
	outreg2 army using "Data/Output/Violence/table2d.txt", bdec(2) br se append

* Table 3: Impact of Abduction on Social and Political Participation

	keep if found==1
	svyset [pweight=w_sel_abs], strata(stratum) psu(camp)
	
	svy: logit pol_job abd age age2 age3 $ctrl_short
		margeff, r
		outreg2 abd using "Data/Output/Violence/table3.out", se br symbol(***, **, *) replace
	foreach y of varlist $depvars {
		svy: logit `y' abd $D $ctrl
			margeff, r
			outreg2 abd using "Data/Output/Violence/table3.out", se br symbol(***, **, *) append
		}	
	foreach y of varlist $depvars2 {
		svy: logit `y' abd age age2 age3 $ctrl_short
			di "`y'"
	            margeff, r
			outreg2 abd using "Data/Output/Violence/table3.out", se br symbol(***, **, *) append
		}	
	

* Table 4: Impact of War Experiences (Former Abductees Only)
	svyset [pweight=w_sel_abs], strata(stratum) psu(camp)
	
	svy: logit vote05 $warexp $D $ctrl if abd==1
		margeff, r
		outreg2 $warexp using "Data/Output/Violence/table4.out", se br symbol(***, **, *) dec(3) replace
	svy: logit comm_mobil $warexp $D $ctrl if abd==1
		margeff, r
		outreg2 $warexp using "Data/Output/Violence/table4.out", se br symbol(***, **, *) dec(3) append
	svy: logit group $warexp $D $ctrl if abd==1
		margeff, r
		outreg2 $warexp using "Data/Output/Violence/table4.out", se br symbol(***, **, *) dec(3) append
	svy: logit fight $warexp $D $ctrl if abd==1
		margeff, r
		outreg2 $warexp using "Data/Output/Violence/table4.out", se br symbol(***, **, *) dec(3) append
	svy: logit quarrel $warexp age age2 age3 kitgum $ctrl_short if abd==1
		margeff, r
		outreg2 $warexp using "Data/Output/Violence/table4.out", se br symbol(***, **, *) dec(3) append
	svy: logit threaten $warexp age age2 age3 kitgum $ctrl_short if abd==1
		margeff, r
		outreg2 $warexp using "Data/Output/Violence/table4.out", se br symbol(***, **, *) dec(3) append


* Table 5: Impact of War Experiences on Participation (All Respondents)
	svyset [pweight=w_sel_abs], strata(stratum) psu(camp)
	
	svy: logit vote05 viol_witnessed viol_loss viol_received viol_perp abd abd_lgth $D $ctrl
		margeff, r
		outreg2 viol_witnessed viol_loss viol_received viol_perp abd abd_lgth using "Data/Output/Violence/table5.out", se br symbol(***, **, *) dec(3) replace
			testparm abd viol_*
	svy: logit comm_mobil viol_witnessed viol_loss viol_received viol_perp abd abd_lgth $D $ctrl
		margeff, r
		outreg2 viol_witnessed viol_loss viol_received viol_perp abd abd_lgth using "Data/Output/Violence/table5.out", se br symbol(***, **, *) dec(3) append
			testparm abd viol_*
	svy: logit group viol_witnessed viol_loss viol_received viol_perp abd abd_lgth $D $ctrl
		margeff, r
		outreg2 viol_witnessed viol_loss viol_received viol_perp abd abd_lgth using "Data/Output/Violence/table5.out", se br symbol(***, **, *) dec(3)  append
			testparm abd viol_*
	svy: logit fight viol_witnessed viol_loss viol_received viol_perp abd abd_lgth $D $ctrl
		margeff, r
		outreg2 abd viol_witnessed viol_loss viol_received viol_perp abd abd_lgth using "Data/Output/Violence/table5.out", se br symbol(***, **, *) dec(3)  append
			testparm abd viol_*
	svy: logit quarrel viol_witnessed viol_loss viol_received viol_perp abd abd_lgth $D $ctrl_short
		margeff, r
		outreg2 viol_witnessed viol_loss viol_received viol_perp abd abd_lgth using "Data/Output/Violence/table5.out", se br symbol(***, **, *) dec(3)  append
			testparm abd viol_*
	svy: logit threaten viol_witnessed viol_loss viol_received viol_perp abd abd_lgth age age2 age3 kitgum $ctrl_short
		margeff, r
		outreg2 viol_witnessed viol_loss viol_received viol_perp abd abd_lgth using "Data/Output/Violence/table5.out", se br symbol(***, **, *) dec(3)  append
			testparm abd viol_*
		


* Table 6: Relative Explanatory Power of the Correlates of Participation
	
	svyset [pweight=w_abs2], strata(stratum) psu(camp)
	
	quietly svy: logit vote05 $covars $D
		quietly margeff, r
		outreg2 $covars using "Data/Output/Violence/table6.out", se br symbol(***, **, *) dec(3) replace
	quietly svy: logit comm_mobil $covars $D
		quietly margeff, r
		outreg2 $covars using "Data/Output/Violence/table6.out", se br symbol(***, **, *) dec(3) append
	
	quietly svy: reg viol_total $D abd
		outreg2 abd using "Data/Output/Violence/table6b.out", se br symbol(***, **, *) dec(3) replace
		foreach y of varlist viol_received viol_witnessed viol_loss viol_perp $covars {
			quietly svy: reg `y' abd $D $ctrl
				outreg2 abd using "Data/Output/Violence/table6b.out", se br symbol(***, **, *) dec(3) append
			}	


* Figure 1: Impact of Relaxing the Assumption of Unconfoundedness

   insheet using "Data/V2V-fig1.csv", comma clear names
   gen n=_n
   gen v=""
   replace v=var if _n==4 | _n==6 | _n==7 | _n==8 | _n==9
   tw fpfit ryp rwp if n>9, clpat(shortdash) clw(medium) clc(black) || scatter ryp rwp if n<=9, m(+) ml(v) mc(black) yti("Influence of covariate on voting" "(Increase in R-squared)", margin(right) size(medium)) xti("Influence of covariate on abduction" "(Increase in R-squared)", margin(top) size(medium))  graphr(color(white)) legend(r(2) label(1 "Threshold for binomial covariate to reduce voting ATE by half") label(2 "Influence of pre-war covariates on voting and abduction") size(small)) ysize(5) xsize(6.5)
